@@ -7,15 +7,15 @@ from django.utils.translation import gettext_lazy as _
 
 class RefreshToken(models.Model):
     key = models.CharField(_("Key"), max_length=40, primary_key=True)
-    user = models.OneToOneField(
+    user = models.ForeignKey(
         settings.AUTH_USER_MODEL, related_name='refresh_token',
         on_delete=models.CASCADE, verbose_name=_("User")
     )
     created = models.DateTimeField(_("Created"), auto_now_add=True)
 
     class Meta:
-        verbose_name = "Refresh Token"
-        verbose_name_plural = "Refresh Tokens"
+        verbose_name = _("Refresh Token")
+        verbose_name_plural = _("Refresh Tokens")
 
     def save(self, *args, **kwargs):
         if not self.key:
