@@ -1,10 +1,11 @@
 from rest_framework import parsers, renderers
-from rest_framework.authtoken.models import Token
+from ..models.access_token import AccessToken as Token
 from oauth2_provider.models import AccessToken
 from rest_framework.response import Response
 from rest_framework.views import APIView
 from ..models.refresh_token import RefreshToken
 from rest_framework.permissions import IsAuthenticated
+from .utils import get_token_from_request
 
 
 class LogoutView(APIView):
@@ -15,12 +16,14 @@ class LogoutView(APIView):
 
     def post(self, request, *args, **kwargs):
         if request.user.is_authenticated:
-            Token.objects.filter(user=request.user).delete()
-            AccessToken.objects.filter(user=request.user).delete()
-            RefreshToken.objects.filter(user=request.user).delete()
-            return Response({
-                'result': True,
-            })
+            token = get_token_from_request(request)
+            if token is not None:
+                Token.objects.filter(key=token).delete()
+                AccessToken.objects.filter(token=token).delete()
+                RefreshToken.objects.filter(key=token).delete()
+                return Response({
+                    'result': True,
+                })
         return Response({
             'result': False,
         }, status=401)
